%global commit 32a8f7304d0e705d36dd9644707552939c67f547
%global shortcommit %(c=%{commit}; echo ${c:0:7})
%global docrepo uwsgi-docs
%global _python_bytecompile_errors_terminate_build 0

Name:           uwsgi
Version:        2.0.17.1
Release:        1%{?dist}
Summary:        Fast, self-healing, application container server
Group:          System Environment/Daemons
License:        GPLv2 with exceptions
URL:            https://github.com/unbit/uwsgi
Source0:        http://projects.unbit.it/downloads/uwsgi-%{version}.tar.gz
Source1:        oss.ini
Source2:        uwsgi.service
Source3:        emperor.ini
Source4:        https://github.com/unbit/%{docrepo}/archive/%{commit}/%{docrepo}-%{shortcommit}.tar.gz
Source7:        uwsgi.tmpfiles

#%if %{with python3}
BuildRequires:  python%{python3_pkgversion}-devel
#%endif

#BuildRequires:  httpd-devel

Requires(pre):   shadow-utils
Requires(post):  chkconfig
Requires(preun): chkconfig
Requires(preun): initscripts

%filter_requires_in %{_usrsrc}
%filter_provides_in %{_usrsrc}
%filter_provides_in %{_libdir}/uwsgi/.*\.so$
%filter_setup

%description
uWSGI is a fast (pure C), self-healing, developer/sysadmin-friendly
application container server.  Born as a WSGI-only server, over time it has
evolved in a complete stack for networked/clustered web applications,
implementing message/object passing, caching, RPC and process management.
It uses the uwsgi (all lowercase, already included by default in the Nginx
and Cherokee releases) protocol for all the networking/interprocess
communications.  Can be run in preforking mode, threaded,
asynchronous/evented and supports various form of green threads/co-routine
(like uGreen and Fiber).  Sysadmin will love it as it can be configured via
command line, environment variables, xml, .ini and yaml files and via LDAP.
Being fully modular can use tons of different technology on top of the same
core.

#python

# %if %{with python3}
# %package -n uwsgi-plugin-python%{python3_pkgversion}-gevent
# Summary:  uWSGI - Plugin for Python %{python3_version} GEvent support
# Group:    System Environment/Daemons
# Requires: uwsgi-plugin-python%{python3_pkgversion} = %{version}-%{release}, libevent

# %description -n uwsgi-plugin-python%{python3_pkgversion}-gevent
# This package contains the Python %{python3_version} gevent plugin for uWSGI
# %endif

#mod_proxy

# %package -n mod_proxy_uwsgi
# Summary:  uWSGI - Apache2 proxy module
# Group:    System Environment/Daemons
# Requires: uwsgi = %{version}-%{release}, httpd

# %description -n mod_proxy_uwsgi
# Fully Apache API compliant proxy module

%prep
%setup -q
cp -p %{SOURCE1} buildconf/
#echo "plugin_dir = %{_libdir}/uwsgi" >> buildconf/oss.ini

%build
CFLAGS="%{optflags} -Wno-error -Wno-unused-but-set-variable" %{__python3} uwsgiconfig.py --build oss.ini

# python plugin
# %if %{with python3}
# CFLAGS="%{optflags} -Wno-unused-but-set-variable" %{__python3} uwsgiconfig.py --plugin plugins/python oss python%{python3_pkgversion}
# CFLAGS="%{optflags} -Wno-unused-but-set-variable" %{__python3} uwsgiconfig.py --plugin plugins/gevent oss python%{python3_pkgversion}_gevent
# CFLAGS="%{optflags} -Wno-unused-but-set-variable" %{__python3} uwsgiconfig.py --plugin plugins/tornado oss python%{python3_pkgversion}_tornado
# %endif

# mod_uwsgi_proxy
# %{_httpd_apxs} -Wc,-Wall -Wl -c apache2/mod_proxy_uwsgi.c

%install
mkdir -p %{buildroot}%{_sysconfdir}/uwsgi.d
#mkdir -p %{buildroot}%{_usrsrc}/uwsgi/%{version}

mkdir docs
tar -C docs/ --strip-components=1 -xvzf %{SOURCE4}
#tar -C %{buildroot}%{_usrsrc}/uwsgi/%{version} --strip-components=1 -xvzf %{SOURCE0}
cp docs/Changelog-%{version}.rst CHANGELOG
rm -f docs/.gitignore

install -D -p -m 0755 uwsgi %{buildroot}%{_sbindir}/uwsgi
#install -p -m 0755 *_plugin.so %{buildroot}%{_libdir}/uwsgi # for python plugin

install -D -p -m 0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/uwsgi.ini

install -D -p -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/uwsgi.service
install -D -p -m 0644 %{SOURCE7} %{buildroot}%{_tmpfilesdir}/uwsgi.conf

# install -D -p -m 0755 apache2/.libs/mod_proxy_uwsgi.so %{buildroot}%{_httpd_moddir}/mod_proxy_uwsgi.so

%pre
getent group uwsgi >/dev/null || groupadd -r uwsgi
getent passwd uwsgi >/dev/null || \
    useradd -r -g uwsgi -d /run/uwsgi -s /sbin/nologin \
    -c "uWSGI daemon user" uwsgi
exit 0

%post

echo "Executing systemd post-install tasks"
%if 0%{?systemd_post:1}
    %systemd_post uwsgi.service
%else
    if [ $1 -eq 1 ] ; then
        # Initial installation
        /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    fi
%endif

%preun
echo "Executing systemd pre-uninstall tasks"
%if 0%{?systemd_preun:1}
    %systemd_preun uwsgi.service
%else
    if [ $1 -eq 0 ] ; then
        # Package removal, not upgrade
        /bin/systemctl --no-reload disable uwsgi.service > /dev/null 2>&1 || :
        /bin/systemctl stop uwsgi.service > /dev/null 2>&1 || :
    fi
%endif

%postun
echo "Executing systemd post-uninstall tasks"
%if 0%{?systemd_postun:1}
    %systemd_postun uwsgi.service
%else
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    if [ $1 -ge 1 ] ; then
        # Package upgrade, not uninstall
        /bin/systemctl try-restart uwsgi.service >/dev/null 2>&1 || :
    fi
%endif

%files
%{_sbindir}/uwsgi
%config(noreplace) %{_sysconfdir}/uwsgi.ini
%{_unitdir}/uwsgi.service
%{_tmpfilesdir}/uwsgi.conf
%dir %{_sysconfdir}/uwsgi.d
%doc README CHANGELOG
%{!?_licensedir:%global license %%doc}
%license LICENSE

# %if %{with python3}
# %files -n python%{python3_pkgversion}-uwsgidecorators
# %defattr(-,root,root,-)
# %{python3_sitelib}/*
# %endif

# %if %{with python3}
# %files -n uwsgi-plugin-python%{python3_pkgversion}-gevent
# %{_libdir}/uwsgi/python%{python3_pkgversion}_gevent_plugin.so
# %endif

# %files -n mod_proxy_uwsgi
# %{_httpd_moddir}/mod_proxy_uwsgi.so

%changelog
* Mon Jan 07 2019 Mickey J Winters <mjw271@jla.rutgers.edu> - 2.0.17.1-1
- made separate package from scratch for rutgers (go.rutgers.edu)
